# Summary of Undocumented Objects

- Module - `gtoolz`
- Constant - `gtoolz.BLACK`
- Method - `gtoolz.MenuBox.__init__`
- Method - `gtoolz.MenuBox.add_selection`
- Instance Variable - `gtoolz.MenuBox.bclr`
- Instance Variable - `gtoolz.MenuBox.center`
- Instance Variable - `gtoolz.MenuBox.clines`
- Instance Variable - `gtoolz.MenuBox.cnt`
- Instance Variable - `gtoolz.MenuBox.msgs`
- Instance Variable - `gtoolz.MenuBox.name`
- Instance Variable - `gtoolz.MenuBox.selections`
- Method - `gtoolz.MenuBox.show`
- Instance Variable - `gtoolz.MenuBox.title`
- Constant - `gtoolz.RESET`
- Constant - `gtoolz.SCRIPT`
- Instance Variable - `gtoolz.Spinner.COLOR`
- Instance Variable - `gtoolz.Spinner.RESET`
- Instance Variable - `gtoolz.Spinner.TIME_COLOR`
- Instance Variable - `gtoolz.Spinner.TXT_COLOR`
- Method - `gtoolz.Spinner.__enter__`
- Method - `gtoolz.Spinner.__exit__`
- Instance Variable - `gtoolz.Spinner._screen_lock`
- Instance Variable - `gtoolz.Spinner.busy`
- Instance Variable - `gtoolz.Spinner.centered`
- Instance Variable - `gtoolz.Spinner.chr_cnt`
- Instance Variable - `gtoolz.Spinner.clr_cnt`
- Instance Variable - `gtoolz.Spinner.color`
- Instance Variable - `gtoolz.Spinner.delay`
- Instance Variable - `gtoolz.Spinner.elapsed`
- Instance Variable - `gtoolz.Spinner.etime`
- Instance Variable - `gtoolz.Spinner.prog`
- Method - `gtoolz.Spinner.spin_backover`
- Method - `gtoolz.Spinner.spin_proc`
- Instance Variable - `gtoolz.Spinner.spinner`
- Instance Variable - `gtoolz.Spinner.start_time`
- Instance Variable - `gtoolz.Spinner.style`
- Instance Variable - `gtoolz.Spinner.time_color`
- Method - `gtoolz.Spinner.write_next`
- Method - `gtoolz.ThreadWithReturn.__init__`
- Method - `gtoolz.ThreadWithReturn.join`
- Method - `gtoolz.ThreadWithReturn.run`
- Method - `gtoolz.Transcript.__init__`
- Method - `gtoolz.Transcript.flush`
- Instance Variable - `gtoolz.Transcript.terminal`
- Method - `gtoolz.Transcript.write`
- Variable - `gtoolz.__version__`
- Variable - `gtoolz.bg_colors_d`
- Function - `gtoolz.bool_val_demo`
- Variable - `gtoolz.dtime`
- Variable - `gtoolz.fg_colors_d`
- Variable - `gtoolz.styles_d`
- Function - `gtoolz.transcript_demo`